/*
Copyright (C) 2009 -  Claudio Salvadori 
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef CXML_H
#define CXML_H

#include "IXml.h"

/**
 * \file CXml.h
 *\date  Created on: 30-mar-2009
 *\author  Author: Claudio Salvadori
 *\brief DAQ specific xml parsing class:
 *	class for xml parsing using xml_schema input.xsd
 */

 /**
 * \class CXml
 *\brief DAQ specific xml parsing class:
 *	class for xml parsing using xml_schema input.xsd
 */
class CXml: implements IXml{

	public:
		/**\brief Constructor
		*\param path_xml 	Xml file path (input)
		*\param def 	Pointer to stream definition structure (output)
		*\param metadata 	Pointer to metadata vector (output) 
		*/
		CXml(char* path_xml, struct SDef* def, vector<struct SMData>* metadata, string* title);

		/**\brief Destructor*/
		~CXml();
		
		/**\brief Initialize the parser
		*\return This method return one of the possible value from enum*/
		virtual x_ret init();
		
		/**\brief This method make the parsing operation and fill def and metadata (validating the parsed value)
		*\param title This is a pointer to a variable contains the title of the output vector (output)
		*\return This method return one of the possible value from enum*/
		virtual x_ret parseXml();
		
	private:
		struct SDef*						x_def;				/**<SDef variable to fill with the data parsed from xml file */
		vector<struct SMData>*					x_meta;				/**<Metadata vector*/
		string*			    				x_title;			/**<Title*/
		const char*						x_path;				/**<Path of xml file*/
		
		x_style							style;				/**<Choosen xml file style \see x_style*/
		x_msg_type						x_c_type;			/**<Character type for special character \see x_msg_type*/
		x_msg_type						x_m_type;			/**<Character type for handshake msg \see x_msg_type*/
				
		DOMNode*						def_node;			/**<DOMDocument pointer*/
		DOMNode*						root_node;			/**<DOMNode pointer for root node*/
		DOMNode*						stream_node;			/**<DOMNode pointer for stream node*/
		DOMNode*						serial_node;			/**<DOMNode pointer for serial serial presets node*/
		DOMNode*						option_node;			/**<DOMNode pointer for serial stream  option node*/
		DOMNode*						pkt_node;			/**<DOMNode pointer for packet description*/
		DOMNode*						handshk_node;			/**<DOMNode pointer for handshaking node*/
		DOMNode*						handshk_pkt_node;		/**<DOMNode pointer for handshaking packet node*/
		DOMNode*						data_node;			/**<DOMNode pointer for data node*/
					
		CXMLParser*		 				x_parser;			/**<Pointer to Xml parser*/
		
		/**\brief Check if the stream definition is correct and fill x_def and title
		*\return This method return one of the possible value from enum \see x_ret */
		x_ret fillDefinition(void);
		
		
		/**\brief Check if the data definition is correct and fill x_meta
		*\return This method return one of the possible value from enum \see x_ret */
		x_ret fillData(void);
			
		/**\brief Convert decimal value (write like a sting of char) into hexadecimal value
		*\param 	ls lowest signifivative value
		*\param 	hs highest signifivative value
		*\return return the hexadecimal value*/
		unsigned char dec2hex(char ls, char hs);
		
		/**\brief Convert a string (char*) in type var_type
		*\param 	ret string that contains the value read from the xml-tree
		*\param 	size total size in byte of the field
		*\return return one of the type of var_type*/
		var_type dataType(char* ret, unsigned long size);

		/**\brief Convert a string (char*) in type data_semantic
		*\param 	ret string that contains the value read from the xml-tree
		*\return return one of the semantic type of data_semantic*/
		data_semantic semanticType(char* ret);

		/**\brief Fill the preset field of x_def for serial
		*\return return one of the x_ret value*/
		x_ret serial(void);

		/**\brief Fill the preset field of x_def for usb
		*\return return one of the x_ret value*/
		x_ret usb(void);

		/**\brief Fill the preset field of x_def for file
		*\return return one of the x_ret value*/
		x_ret file(void);

		/**\brief Fill the preset field of x_def for pipe
		*\return return one of the x_ret value*/
		x_ret pipe(void);

		/**\brief Fill the preset field of x_def for socket
		*\return return one of the x_ret value*/
		x_ret socket(void);

		/************************************************************************/
		/*  ADD HERE THE FUNCTION DEFINITION FOR THE NEW COMMUNICATION DEVICE   */
		/************************************************************************/

		/**\brief Fill the structure x_def->s_Option \see SOption
		*\return return one of the x_ret value*/
		x_ret streamOption(void);

		/**\brief Read from xml tree the size of the packet
		*\return return one of the x_ret value*/
		x_ret lengthPacket(void);

		/**\brief Fill the structure x_def->s_Handshk \see SHandshaking
		*\return return one of the x_ret value*/
		x_ret handshake(void);
};
#endif
