/*
Copyright (C) 2009 -  Claudio Salvadori 
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef DAQERROR_H
#define DAQERROR_H

/**
 *\file DAQError.h
*
 *\date  Created on: 21-08-2009
 *\author  Author: Claudio Salvadori
 *\brief  Error enumerations for the UI CDaq
 */

/**
*\brief Enumeration of possible result CDaq class method.
*/
enum daq_ret{
	D_RET_OK		=	0,	/**<Ok*/
	
	D_INIT_ERR		=	1,	/**<Error in parser init*/
	D_PARSE_ERR		=	2,	/**<Error in parsing*/
	D_XML_PARSER_ERR	=	3,	/**<Error in parsing*/
	D_XML_P_FILE_ERR	=	4,  	/**<Syntax error in file.xml*/
	D_XML_P_DOM_ERR		=	5,  	/**<Error in DOM parsing*/
	D_XML_P_UN_ERR		=	6,  	/**<Unexpected exception during parsing*/
	D_P_STYLE_ERR		=	7,  	/**<Style error*/
	D_P_TITLE_ERR		=	8, 	/**<Title error*/
	D_P_STREAM_ERR		=	9,	/**<Stream node searching error*/
	D_P_STREAM_T_ERR	=	10,	/**<Stream type error*/
	D_P_STREAM_N_ERR	=	11,	/**<Stream name error*/
	D_P_STREAM_FT_ERR	=	12, 	/**<Stream file type error*/
	D_P_STREAM_C_ERR	=	13, 	/**<Stream channel error*/
	D_P_PKT_ERR		=	14,	/**<Packet node searching error*/
	D_P_PKT_S_ERR		=	15, 	/**<Packet size error*/
	D_P_DTA_ERR		=	16, 	/**<Data node searching error*/
	D_P_DTA_N_ERR		=	17, 	/**<Data name error*/
	D_P_DTA_P_ERR		=	18, 	/**<Data position error*/
	D_P_DTA_S_ERR		=	19, 	/**<Data size error*/
	D_P_DTA_T_ERR		=	20, 	/**<Data type error*/
	D_GENERIC_ERR		=	21,	/**<Generic error*/
	D_VAL_MDATA_ERR		=	22,	/**<Validate metadata error*/
	D_P_S_STREAM_ERR	=	23,	/**<Serial stream node searching error*/
	D_P_BAUD_RATE_ERR	=	24, 	/**<Baud rate error*/
	D_P_DATA_BITS_ERR	=	25, 	/**<Data bits error*/
	D_P_PARITY_ERR		=	26,	/**<Parity bits error*/
	D_P_STOP_ERR		=	27,	/**<Stop bits error*/
	D_P_HAND_ERR		=	28,	/**<Handshaking node searching error*/
	D_P_HAND_P_ERR		=	29,	/**<Handshaking packet node searching error*/
	D_P_H_SEND_ERR		= 	30,	/**<Send packet error*/
	D_P_O_STREAM_ERR	= 	31,	/**<Option stream node searching error*/
	D_P_O_TYPE_ERR		= 	32,	/**<Option type error*/
	D_P_O_START_ERR		= 	33,	/**<Start character error*/
	D_P_O_END_ERR		= 	34,	/**<End character error*/
	D_P_O_ESC_ERR		= 	35,	/**<Escape character error*/
	D_P_H_ACK_ERR		= 	36,	/**<Ack packet error*/
	D_P_H_NACK_ERR		= 	37,	/**<Nack packet error*/
	D_P_H_STYLE_ERR		=	38,	/**<Handshaking style error*/

	D_OPTION_ERR		=	101, 	/**<Option struct doesn't fill correctly*/
	
	D_D_EMPTY_ERR		=	102, 	/**<Empty input buffer (decode)*/
	D_D_ESCAPE_ERR		=	103, 	/**<Escape character in the wrong position*/
	
	D_M_EMPTY_ERR		=	104, 	/**<Empty input buffer (divide in messages)*/
	D_M_LENGTH_ERR		=	105,	/**<Wrong packet size (divide in messages)*/ 
	
	D_F_OPEN_ERR		=	106,	/**<Error in file opening*/
	D_F_READ_ERR		=	107,	/**<Error in file reading*/
	D_F_R_LENGTH_ERR	=	108,	/**<Error: read shortest packet in file*/
	D_F_R_START_ERR		=	109,	/**<Error in reading file: start character doesn't find*/
	D_F_R_END_ERR		=	110,	/**<Error in reading file: end character doesn't find*/
	D_F_EOS			=	111,	/**<OK end of stream for files*/
	
	D_S_PRESET_MISS_ERR	=	112,	/**<Error: missing the serial preset*/
	D_S_OPEN_ERR		=	113,  	/**<Error in serial open*/
	D_S_G_CHAR_ERR		=	114, 	/**<Error: serial get char*/
	D_S_P_CHAR_ERR		=	115,	/**<Error: serial put char*/
	D_S_READ_ERR		=	116,  	/**<Error in receiving from serial*/
	D_S_WRITE_ERR		=	117, 	/**<Error in sending by serial*/
	D_S_LENGHT_ERR		=	118, 	/**<Error: read shortest/longest packet from serial*/
	D_S_R_TIMEOUT_ERR	=	119, 	/**<Error: serial receive timeout error*/
	D_S_T_TIMEOUT_ERR	=	120, 	/**<Error: serial transmit timeout error*/
	D_S_NACK		=	121, 	/**<Nack received during handshking (serial)*/
	D_S_GEN_ERR		=	122, 	/**<Generic error(serial)*/
	
	D_P_INIT_ERR		=	123, 	/**<Error in pipe init*/
	D_P_G_CHAR_ERR		=	124, 	/**<Error: pipe get char*/
	D_P_P_CHAR_ERR		=	125,	/**<Error: pipe put char*/
	D_P_READ_ERR		=	126, 	/**<Error in receiving from pipe*/
	D_P_WRITE_ERR		=	127, 	/**<Error in sending by pipe*/
	D_P_LENGHT_ERR		=	128, 	/**<Error: read shortest/longest packet from pipe*/
	D_P_R_TIMEOUT_ERR	=	129, 	/**<Error: pipe receive timeout error*/
	D_P_T_TIMEOUT_ERR	=	130,	/**<Error: pipe transmit timeout error*/
	D_P_NACK		=	131,	/**<Nack received during handshking (pipe)*/
	D_P_GEN_ERR		=	132, 	/**<Generic error(pipe)*/
	D_P_NOTIMPL		=	133,	/**<Not implemented*/

	D_SO_INIT_ERR		=	134,	/**<Error in initializing the socket*/
	D_SO_INIT_V_ERR		=	135,	/**<Error in initializing the socket(not correct version)*/
	D_SO_INIT_R_ERR		=	136,	/**<Error in initializing the socket(resolving server)*/
	D_SO_INIT_C_ERR		=	137,	/**<Error in initializing the socket(create socket error)*/
	D_SO_INIT_CONN_ERR	=	138,	/**<Error in initializing the socket(client connection error)*/
	D_SO_WRITE_ERR		=	139,	/**<Socket write error*/
	D_SO_LENGHT_ERR		=	140,	/**<Error: read shortest/longest packet from socket*/
	D_SO_NACK		=	141,	/**<Socket: Nack received during handshking*/
	D_SO_GEN_ERR		=	142, 	/**<Socket: Generic error*/
	D_SO_READ_ERR		=	143, 	/**<Socket read error*/
	D_SO_CLOSED_ERR		=	144, 	/**<Socket connection closed*/

	/**********************************************************************************************/
	/*        ADD HERE THE RETURN ERRORS FROM THE NEW COMMUNICATION DEVICE CLASS                  */
	/**********************************************************************************************/	

	D_META_ERR		=	201,	/**<Metadata vector is empty*/
	D_H_NULL_ERR		=	202,	/**<Header vector is pointed by a NULL pointer*/
	D_H_EMPTY_ERR		=	203,	/**<Header vector is empty*/
	D_D_NULL_ERR		=	204, 	/**<Data vector is pointed by a NULL pointer*/
	D_F_EMPTY_ERR		=	205,  	/**<Data vector is empty*/

};

#endif
