/*
Copyright (C) 2009 - Paolo Pagano
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/**
 *\file LoopDAQEvent.cpp
 *\date  Created on: 26-08-2009
 *\author  Author: Paolo Pagano
 *\brief  Post-processing functions */

#include <stdlib.h>
#include "TH1D.h"
#include "TGraph.h"
#include "Riostream.h"
#include "TROOT.h"
#include "TFile.h"
#include "TCanvas.h"
#include "TNetFile.h"
#include "TRandom.h"
#include "TTree.h"
#include "TBranch.h"
#include "TClonesArray.h"
#include "TStopwatch.h"
#include "DAQEvent.h"
#include "fdy.h"
#include "Show_image.h"
#define GRAY_LEVEL 256
#define NIMAGES 50

DAQEvent * event;
TCanvas *c1;
TFile* f, *g;
TH1F *hp;
Float_t  y[NIMAGES];
extern unsigned int h_old[GRAY_LEVEL]; 		/* Previous picture histogram buffer*/
extern unsigned int h_act[GRAY_LEVEL];		/* Actual picture histogram buffer*/


void init(char * output){
  g = new TFile ( output, "RECREATE");
  hp = new TH1F("hp","Likelihood Index",30, -0.5,29.5);
  
}

int main(int argc, char**argv){
#ifdef DAQIMAGE
	if ( argc < 3 ) {
		cout << "Synapsis: LoopDAQEvent <in.root> <out.root> " <<  endl;
		exit(1);
	}
	init ( argv[2] );
	f= new TFile(argv[1]);

	//   Read Tree named "T" in memory. Tree pointer is assigned the same name
	TTree *T = (TTree*)f->Get("T");

	DAQSData *mydaq;
	DAQPayload *mypayload;
	TBranch *branch  = T->GetBranch("event");
	branch->SetAddress(&event);
	Int_t nevent = T->GetEntries();
	Int_t nselected = 0;
	Int_t graph_abscissa =0;
	for (Int_t i=1;i<nevent;i++) {
		if(i%50 == 0) printf("DAQEvent:%d\n",i);
		cout << "prima di getEntry: " <<  endl;
		T->GetEntry(i);                
		if (event->GetNDAQSDatas() > 687)continue;
		cout << "Dopo: " << endl;
		TClonesArray *myarray = event->GetDAQSDatas();
		if (myarray) mydaq = (DAQSData *) myarray->First();
		if (!mydaq) continue;
		cerr << "Pointer is: " << myarray << endl;
		mydaq->printData();
		mypayload = mydaq->getPayload();
		y[graph_abscissa] = fdy_cd(mypayload->image_, IMAGE_BUFFER);
		TAxis *ax = hp->GetXaxis();
		cerr << "Abscissa is: " << ax->GetBinCenter(graph_abscissa) << endl;
		hp->SetBinContent((ax->GetBinCenter((Float_t)graph_abscissa)) + 2, y[graph_abscissa]);
		graph_abscissa += 1;
		initRenderer();
		renderImage((unsigned char*) mypayload->image_, 160, 120, 1);	
		getchar();
		nselected++;
		event->Clear();     //clear tracks array
	}

	f->Close();
	g->cd();
	hp->SetDrawOption("l");
	hp->Draw();

	g->Write();
#else
	cout << "Error: this executable has not been compiled with the DAQIMAGE symbol." <<  endl;
	cout << "Recopile with: make image" <<  endl;	
	exit(1);
#endif  
}

