/*
Copyright (C) 2009 -  Claudio Salvadori 
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


/*************************************************************************/
/* 	    A simple server in the internet domain using TCP.		 */
/*  		The port number is passed as an argument.		 */
/*************************************************************************/

#include <sys/types.h> 
#include <sys/socket.h>
#include <stdlib.h>											
#include <netdb.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <iostream>
#include <string.h>

//Ack value
#define ACK	"1"	
//Nak value
#define NAK	"0"	

using namespace std;
int main(int argc, char *argv[])
{
	unsigned int counter = 0;
	int sockfd, newsockfd, portno, clilen;
	char buffer[256];
	struct sockaddr_in serv_addr, cli_addr;
	int n;
	
	//Checking the port number
	if (argc < 2) {
		cout << "Synapsis: ./exe/SocketExample <Port.Number> " <<  endl;
		exit(1);
	}

	//Open a socket
	sockfd = socket(AF_INET, SOCK_STREAM, 0);
	if (sockfd < 0) {
		cerr << "ERROR opening socket" << endl;
 		exit(1);
	}
	
	//Fill the server address structure
	bzero((char *) &serv_addr, sizeof(serv_addr));
	portno = atoi(argv[1]);
	serv_addr.sin_family = AF_INET;		//Internet socket
	serv_addr.sin_addr.s_addr = INADDR_ANY;	//Connect to any client
	serv_addr.sin_port = htons(portno);	//Port number

	//Binding operation
	if (bind(sockfd, (struct sockaddr *) &serv_addr, sizeof(serv_addr)) < 0){
		cerr << "ERROR on binding" << endl;
		exit(1);
	}

	printf("Waiting for connection... \n");

	//Listening operation
	listen(sockfd,5);
	clilen = sizeof(cli_addr); 

	//Accepting a client
	newsockfd = accept(sockfd, (struct sockaddr *) &cli_addr, (socklen_t*)&clilen);
	if (newsockfd < 0){
		cerr << "ERROR on accept" << endl;
		exit(1);
	}

	printf("Connected! \n");

	//Reading the handshaking word
	bzero(buffer,256);
	n = read(newsockfd,buffer,255);
	if (n < 0){
		cerr << "ERROR reading from socket" << endl;
		exit(1);	
	}
	
	printf("Here is the massage: %s\n",buffer);

	//Checking if the handshaking packet is correct and answer
	if(!strcmp (buffer, "1")){
		n = write(newsockfd, ACK, 1);
		if (n < 0){
			cerr << "ERROR writing to socket" << endl;
			exit(1);
		}
	}else{
		n = write(newsockfd, NAK, 1);
		if (n < 0){
			cerr << "ERROR writing to socket" << endl;
			exit(1);
		}
	}

	//Infinite cycle for sending packets
	while(1){
		counter ++;
		unsigned char packet[10];
		packet[0] = 0x02;
		packet[1] = (unsigned char)'D';
		packet[2] = (unsigned char)'A';
		packet[3] = (unsigned char)'Q';
		packet[4] = (unsigned char)'*';
		packet[5] = (unsigned char)((counter >> 24) & 0xFF);
		if((packet[5] == 0x02) || (packet[5] == 0x03))
			packet[5] = 0;
		packet[6] = (unsigned char)((counter >> 16) & 0xFF);
		if((packet[6] == 0x02) || (packet[6] == 0x03))
			packet[6] = 0;
		packet[7] = (unsigned char)((counter >> 8) & 0xFF);
		if((packet[7] == 0x02) || (packet[7] == 0x03))
			packet[7] = 0;
		packet[8] = (unsigned char)((counter) & 0xFF);
		if((packet[8] == 0x02) || (packet[8] == 0x03))
			packet[8] = 0;
		packet[9] = 0x03;
		n = write(newsockfd, packet, 10);
		if (n < 0){
			cerr << "ERROR writing to socket" << endl;
			exit(1);
		}else
		cout << "Sent packet: " << hex << (int)packet[0] << hex << (int)packet[1] << hex << (int)packet[2] << hex << (int)packet[3] <<
			hex <<(int) packet[4] << hex << (int)packet[5] << hex << (int)packet[6] << hex << (int)packet[7] << hex << (int)packet[8] <<
			hex << (int)packet[9] << hex <<(int) packet[10] << endl;
	} 


	return 0; 
}
