/*
Copyright (C) 2009 - Paolo Pagano and Claudio Salvadori
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/**
 * @file   DAQPayload.h
 * @author Paolo Pagano and Claudio Salvadori
 * @date   22-08-2009
 * 
 * @brief  This file contains the stucture to store the data
 * according with xml file
 */

#ifndef DAQPAYLOAD_H
#define DAQPAYLOAD_H

#ifdef DAQIMAGE
#define IMAGE_BUFFER	19200
#endif

#ifdef DAQSOCKET
#define MESSAGE_BUFFER	4
#endif

#ifdef DAQTIMERAVR
#define NUMBER_OF_PACKET	3
#endif

/**
*\brief Structure that describe the packet payload according with xml file
*\warning This structure has to be modified everytime the xml file payload description is changed
*/
struct DAQPayload{

#ifdef DAQIMAGE
	UShort_t  	width_;			/**<Image width*/
	UShort_t  	height_;		/**<Image height*/
	ULong_t  	duration_;		/**<Image duration*/
	UShort_t  	lost_;			/**<Frame lost (1 true, 0 false)*/
	UShort_t  	ymean_;			/**<Luminance mean value*/
	UChar_t  	image_[IMAGE_BUFFER];	/**<Raw image*/
#endif

#ifdef DAQSOCKET
	Char_t  	message_[MESSAGE_BUFFER];   	/**<Message arrived*/
	UInt_t  	counter_;			/**<Counter value*/
#endif

#ifdef DAQTIMERAVR
	UShort_t  	type_[NUMBER_OF_PACKET];   	/**<Timer tick in seconds*/
	UInt_t  	ncycles_[NUMBER_OF_PACKET];	/**<Value of previous timestamp*/
	UShort_t  	ts_[NUMBER_OF_PACKET];   	/**<Timer tick in seconds*/
	UChar_t  	seqNum_[NUMBER_OF_PACKET];  	/**<Packet number*/
	UChar_t  	bcnNum_[NUMBER_OF_PACKET];   	/**<Beacon number*/
#endif

#ifdef DAQTIMERUW_EE
	UInt_t  	time_;		/**<End-to-End duration 
				(from application layer to application layer)*/
	UShort_t  	length_;   	/**<Packet lenght*/
#endif


#ifdef DAQTIMERUW
	UInt_t  	time_;		/**<Stack duration 
				(from application layer to physical layer)*/
	UShort_t  	length_;   	/**<Packet lenght*/
#endif

};
#endif
